@@ -1,17 +1,20 @@
-(defproject puppetlabs/clj-shell-utils "1.0.2"
+(defproject puppetlabs/clj-shell-utils "2.0.1"
   :description "Clojure shell execution utilities"
 
   :min-lein-version "2.9.0"
 
-  :parent-project {:coords [puppetlabs/clj-parent "3.0.0"]
+  :parent-project {:coords [puppetlabs/clj-parent "7.3.15"]
                    :inherit [:managed-dependencies]}
-
+  :license {:name "Apache-2.0"
+            :url "https://www.apache.org/licenses/LICENSE-2.0.txt"}
+            
   :pedantic? :abort
 
   :test-paths ["test/unit"]
 
   :plugins [[lein-project-version "0.1.0"]
-            [lein-parent "0.3.6"]]
+            [lein-parent "0.3.6"]
+            [puppetlabs/i18n "0.9.0"]]
 
   :source-paths ["src/clj"]
   :java-source-paths ["src/java"]
@@ -34,7 +37,7 @@
                                      :username :env/clojars_jenkins_username
                                      :password :env/clojars_jenkins_password
                                      :sign-releases false}]
-                        ["snapshots" "http://nexus.delivery.puppetlabs.net/content/repositories/snapshots/"]]
-  )
+                        ["snapshots" "https://artifactory.delivery.puppetlabs.net/artifactory/list/clojure-snapshots__local/"]])
+
 
 
